#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.8
visibility:           public
id:                   kan-extensions-5.2.8-LydeDEB2vff2KHJPbZpgSV
key:                  kan-extensions-5.2.8-LydeDEB2vff2KHJPbZpgSV
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  0281b03da6ee36e89157b0193f40a7c0
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.8-LydeDEB2vff2KHJPbZpgSV
depends:
    adjunctions-4.4.4-Ka93c078NeEE2AMsy9YzUt base-4.18.2.1
    comonad-5.0.10-EXUe6qWqQMj9EujznH0ooo
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    distributive-0.6.3-FOnzW44kBjbLaVKLeO1VVK exceptions-0.10.7
    free-5.2-D5qt53JxkZyBtrV8uqwmEj
    invariant-0.6.5-AIM6j00qjPlKj0B8HCUd4e mtl-2.3.1
    profunctors-5.6.3-Dzx15pSWheZIsI1nl8d4qX
    semigroupoids-6.0.2-5bJlexYvMEN2VlSIqlgUv9 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

